==> jersey-server-2.14-sources.jar: org/glassfish/jersey/server/internal/monitoring/CompositeApplicationEventListener.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013-2014 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.jersey.server.internal.monitoring;

import java.util.List;

import org.glassfish.jersey.server.monitoring.ApplicationEvent;
import org.glassfish.jersey.server.monitoring.ApplicationEventListener;
import org.glassfish.jersey.server.monitoring.RequestEvent;
import org.glassfish.jersey.server.monitoring.RequestEventListener;

import jersey.repackaged.com.google.common.collect.Lists;

/**
 * {@link ApplicationEventListener application event listener} that aggregates more event listeners into one.
 * Calling listener methods on this listener will cause calling methods on all aggregated listeners.
 *
 * @author Miroslav Fuksa (miroslav.fuksa at oracle.com)
 */
public class CompositeApplicationEventListener implements ApplicationEventListener {

    private final Iterable<ApplicationEventListener> applicationEventListeners;

    /**
     * Creates a new instance of composite event listener.
     *
     * @param applicationEventListeners List of application event listener that should be aggregated.
     */
    public CompositeApplicationEventListener(final Iterable<ApplicationEventListener> applicationEventListeners) {
        this.applicationEventListeners = applicationEventListeners;
    }

    @Override
    public void onEvent(final ApplicationEvent event) {
        for (final ApplicationEventListener applicationEventListener : applicationEventListeners) {
            applicationEventListener.onEvent(event);
        }
    }

    @Override
    public RequestEventListener onRequest(final RequestEvent requestEvent) {
        final List<RequestEventListener> requestEventListeners = Lists.newArrayList();
        for (final ApplicationEventListener applicationEventListener : applicationEventListeners) {
            final RequestEventListener requestEventListener = applicationEventListener.onRequest(requestEvent);
            if (requestEventListener != null) {
                requestEventListeners.add(requestEventListener);
            }
        }

        return requestEventListeners.isEmpty() ? null
                : new CompositeRequestEventListener(requestEventListeners);
    }
}

==> jersey-server-2.26-b07-sources.jar: org/glassfish/jersey/server/internal/monitoring/CompositeApplicationEventListener.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013-2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * http://glassfish.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.jersey.server.internal.monitoring;

import java.util.ArrayList;
import java.util.List;

import org.glassfish.jersey.server.monitoring.ApplicationEvent;
import org.glassfish.jersey.server.monitoring.ApplicationEventListener;
import org.glassfish.jersey.server.monitoring.RequestEvent;
import org.glassfish.jersey.server.monitoring.RequestEventListener;

/**
 * {@link ApplicationEventListener application event listener} that aggregates more event listeners into one.
 * Calling listener methods on this listener will cause calling methods on all aggregated listeners.
 *
 * @author Miroslav Fuksa
 */
public class CompositeApplicationEventListener implements ApplicationEventListener {

    private final Iterable<ApplicationEventListener> applicationEventListeners;

    /**
     * Creates a new instance of composite event listener.
     *
     * @param applicationEventListeners List of application event listener that should be aggregated.
     */
    public CompositeApplicationEventListener(final Iterable<ApplicationEventListener> applicationEventListeners) {
        this.applicationEventListeners = applicationEventListeners;
    }

    @Override
    public void onEvent(final ApplicationEvent event) {
        for (final ApplicationEventListener applicationEventListener : applicationEventListeners) {
            applicationEventListener.onEvent(event);
        }
    }

    @Override
    public RequestEventListener onRequest(final RequestEvent requestEvent) {
        final List<RequestEventListener> requestEventListeners = new ArrayList<>();
        for (final ApplicationEventListener applicationEventListener : applicationEventListeners) {
            final RequestEventListener requestEventListener = applicationEventListener.onRequest(requestEvent);
            if (requestEventListener != null) {
                requestEventListeners.add(requestEventListener);
            }
        }

        return requestEventListeners.isEmpty() ? null
                : new CompositeRequestEventListener(requestEventListeners);
    }
}
